pub enum Mode {
BlackList,
WhiteList,
}Expand description
Strategy mode that ACL is running
Variants
BlackList
BlackList mode, rejects or bypasses all requests by default
WhiteList
WhiteList mode, accepts or proxies all requests by default